:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _changelog:

Changelog
=========

2.8.2 (not yet released)
------------------------

2.8.1 (March 7th, 2016)
-----------------------

* First release of Grappelli which is compatible with Django 1.9.
